" set leader key
let g:mapleader = "\<Space>"

syntax enable                           " Enables syntax highlighing
set hidden                              " Required to keep multiple buffers open multiple buffers
set wrap                                " Display long lines as just one line
set pumheight=10                        " Makes popup menu smaller
set encoding=utf-8                      " The encoding displayed
set fileencoding=utf-8                  " The encoding written to file
set ruler                               " Show the cursor position all the time
set cmdheight=1                         " More space for displaying messages
set iskeyword+=-                        " treat dash separated words as a word text object"
set mouse=a                             " Enable your mouse
set t_Co=256                            " Support 256 colors

set conceallevel=0                      " So that I can see `` in markdown files
set tabstop=4                           " Insert 2 spaces for a tab
set shiftwidth=4                        " Change the number of space characters inserted for indentation
set smarttab                            " Makes tabbing smarter will realize you have 2 vs 4
set expandtab                           " Converts tabs to spaces
set smartindent                         " Makes indenting smart
set autoindent                          " Good auto indent
set foldmethod=indent

set laststatus=2                        " Always display the status line

set number                              " Line number
set relativenumber                      " Relative line number
set cursorline                          " Enable highlighting of the current line
set showtabline=1                       " show tabs only when there are some

set background=dark                     " tell vim what the background color looks like

set nobackup                            " This is recommended by coc
set nowritebackup                       " This is recommended by coc
set noswapfile

set updatetime=300                      " Faster completion
set timeoutlen=500                      " By default timeoutlen is 1000 ms

set clipboard=unnamedplus               " Copy paste between vim and everything else

set showmode                            " Display edition mode
"set noshowmode                          " We don't need to see things like -- INSERT -- anymore

set incsearch                           " hightlight while searching
set ignorecase                          " Ignore case while searching
set smartcase                           " Override ignorecase if search patern contains upper case
set wildmenu                            " Enable wildmenu

set spell                               " Enable spell checking
set spelllang=fr,en

set nrformats+=alpha                    " letter concidered as number for Ctrl-A or Ctrl-X

"set autochdir                           " Your working directory will always be the same as your working directory

execute "set colorcolumn=" . join(range(81,335), ',')

colorscheme zenburn

" Set completeopt to have a better completion experience
" set completeopt=menuone,noinsert,noselect
" set completeopt=menuone,noselect

" Avoid showing message extra message when using completion
set shortmess+=c

let g:indentLine_setConceal = 0
